MatplotlibWidget — pyqtgraph 0.11.0rc0 documentation

# MatplotlibWidget

class `pyqtgraph.widgets.MatplotlibWidget.` `MatplotlibWidget`(size=(5.0, 4.0), dpi=100)

  Implements a Matplotlib figure inside a QWidget. Use getFigure() and redraw() to interact with matplotlib.

  Example:

      mw = MatplotlibWidget()
      subplot = mw.getFigure().add_subplot(111)
      subplot.plot(x,y)
      mw.draw()

  `__init__`(size=(5.0, 4.0), dpi=100)

    Initialize self. See help(type(self)) for accurate signature.